/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2007 INRIA
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
 */
#ifndef IPV4_PRIVATE_H
#define IPV4_PRIVATE_H

#include "ns3/object.h"
#include "ns3/ipv4-address.h"
#include "ns3/ptr.h"
#include <stdint.h>

namespace ns3 {

class Packet;
class Ipv4L3Protocol;
class TraceContext;
class TraceResolver;
class Ipv4Interface;
class NetDevice;

class Ipv4Private : public Object
{
public:
  static const InterfaceId iid;
  Ipv4Private (Ptr<Ipv4L3Protocol> ipv4);
  virtual ~Ipv4Private ();

  TraceResolver *CreateTraceResolver (TraceContext const &context);
  void Send (Packet const &packet, Ipv4Address source, 
	     Ipv4Address destination, uint8_t protocol);
  Ipv4Interface *FindInterfaceForDevice (Ptr<const NetDevice>device);
  void Receive(Packet& p, Ptr<NetDevice> device);
protected:
  virtual void DoDispose (void);
private:
  Ptr<Ipv4L3Protocol> m_ipv4;
};

} // namespace ns3

#endif /* IPV4_PRIVATE_H */
